summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kscons_kxt/app.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
commitf78eb03afb8c9a380985d26286afc40b4c89b292 (patch)
tree3c087e2f119e645c902958c3bc3c802abf078ad0 /languages/cpp/app_templates/kscons_kxt/app.cpp
parentda1941ccadffe5ae70ee111c53f0ec2b3d990869 (diff)
downloadtdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.tar.gz
tdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'languages/cpp/app_templates/kscons_kxt/app.cpp')
-rw-r--r--languages/cpp/app_templates/kscons_kxt/app.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/cpp/app_templates/kscons_kxt/app.cpp b/languages/cpp/app_templates/kscons_kxt/app.cpp
index 2895fb0a..6b37401d 100644
--- a/languages/cpp/app_templates/kscons_kxt/app.cpp
+++ b/languages/cpp/app_templates/kscons_kxt/app.cpp
@@ -26,14 +26,14 @@
#include <kstdaction.h>
%{APPNAME}::%{APPNAME}()
- : KMainWindow( 0, "%{APPNAME}" ),
+ : TDEMainWindow( 0, "%{APPNAME}" ),
m_view(new %{APPNAME}View(this)),
m_printer(0)
{
// accept dnd
setAcceptDrops(true);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions
@@ -76,7 +76,7 @@ void %{APPNAME}::setupActions()
KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
// custom menu and menu item - the slot is in the class %{APPNAME}View
- KAction *custom = new KAction(i18n("Swi&tch Colors"), 0,
+ TDEAction *custom = new TDEAction(i18n("Swi&tch Colors"), 0,
m_view, TQT_SLOT(switchColors()),
actionCollection(), "switch_action");
@@ -26,14 +26,14 @@
// accept dnd
setAcceptDrops(true);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions